package test;

import javax.swing.*;
import java.awt.event.*;
import java.beans.*;

public class BusinessObject
{
	private int temperature;

	private PropertyChangeSupport pcs;

	public BusinessObject()
	{
		pcs = new PropertyChangeSupport(this); // you would register other backend object in a real application, but this is a simplified example
		temperature = 50;
		pcs.addPropertyChangeListener(new PropertyChangeListener()
		{
			public void propertyChange(PropertyChangeEvent e)
			{
				doImportantTask();
			}
		});
	}

	public synchronized int getTemperature()
	{
		return temperature;
	}

	public synchronized void setTemperature(int temp)
	{
		int oldTemperature = temperature;
		temperature = temp;
		pcs.firePropertyChange(new PropertyChangeEvent(this, "temperature", new Integer(oldTemperature), new Integer(temperature)));
	}

	public synchronized void decreaseTemperature()
	{
		setTemperature(temperature - 1);
	}

	public synchronized void increaseTemperature()
	{
		setTemperature(temperature + 1);
	}

	private void doImportantTask()
	{
		System.out.println(temperature + " : Done important task");
		// or, create and dispatch a new thread
	}

	/* main() for test */
	public static void main(String[] args)
	{
		final BusinessObject bo = new BusinessObject();

		JPanel panel = new JPanel();
		final JLabel label = new JLabel(String.valueOf(bo.getTemperature()));
		final JButton incbtn = new JButton("Increase Temperature");
		final JButton decbtn = new JButton("Decrease Temperature");

		ActionListener acl = new ActionListener()
		{
			public void actionPerformed(ActionEvent e)
			{
				if (e.getSource() == incbtn)
				{
					bo.increaseTemperature();
				}
				else
				{
					bo.decreaseTemperature();
				}
				label.setText(String.valueOf(bo.getTemperature()));
			}
		};

		incbtn.addActionListener(acl);
		decbtn.addActionListener(acl);

		panel.add(incbtn);
		panel.add(label);
		panel.add(decbtn);

		JOptionPane.showMessageDialog(null, panel);
		System.exit(0);
	}
}
