package tical.utils;

import java.awt.Color;

/**
 * @author   grummfy
 * @version 23-02-008
 */
public class Utils
{
	/**
	* Get #ffffff html hex number for a colour
	*
	* @see #toHexString(int)
	* @param c
	*        Color object whose html colour number you want as a string
	* @return # followed by exactly 6 hex digits
	*/
	public final static String color2Hex( Color c )
	{
		String s = Integer.toHexString( c.getRGB() & 0xffffff ).toUpperCase();
		if ( s.length() < 6 )
		{
			// pad on left with zeros
			s = "000000".substring( 0, 6 - s.length() ) + s;
		}
		return '#' + s;
	}

	/**
	 * format : #XXXXXX or #xxxxxx
	 * @param c
	 * @return
	 */
	public final static Color Hex2Color( String c )
	{
		char color[] = c.toCharArray();
		if (color.length != 7)
			throw new IllegalArgumentException ("Bad format : " + c);

		return new Color(
			hexaChar2Int(color[1]) * hexaChar2Int(color[2]),
			hexaChar2Int(color[3]) * hexaChar2Int(color[4]),
			hexaChar2Int(color[5]) * hexaChar2Int(color[6]));
	}

	public final static int hexaChar2Int (char c)
	{
		if ('0' <= c && c <= '9')
			return c - '0';
		else
			if ('a' <= c && c <= 'f')
				return c - 'a' + 10;
			else
				if ('A' <= c && c <= 'F')
					return c - 'A' + 10;
				else
					throw new IllegalArgumentException ("Invalid hexadecimal character: " + c);
	}
}
